@@ -2,19 +2,18 @@
 """Objects, properties, and methods to be shared across other modules in the
 trakt package
 """
-from __future__ import print_function
 import json
 import logging
 import os
+from urllib.parse import urljoin
+
 import requests
-import six
 import sys
 import time
 from collections import namedtuple
 from functools import wraps
-from requests.compat import urljoin
 from requests_oauthlib import OAuth2Session
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from trakt import errors
 
 __author__ = 'Jon Nappi'
@@ -70,6 +69,9 @@ AUTH_METHOD = PIN_AUTH
 #: The ID of the application to register with, when using PIN authentication
 APPLICATION_ID = None
 
+#: Global session to make requests with
+session = requests.Session()
+
 
 def _store(**kwargs):
     """Helper function used to store Trakt configurations at ``CONFIG_PATH``
@@ -90,12 +92,12 @@ def _get_client_info(app_id=False):
     print('If you do not have a client ID and secret. Please visit the '
           'following url to create them.')
     print('http://trakt.tv/oauth/applications')
-    client_id = six.moves.input('Please enter your client id: ')
-    client_secret = six.moves.input('Please enter your client secret: ')
+    client_id = input('Please enter your client id: ')
+    client_secret = input('Please enter your client secret: ')
     if app_id:
         msg = 'Please enter your application ID ({default}): '.format(
             default=APPLICATION_ID)
-        user_input = six.moves.input(msg)
+        user_input = input(msg)
         if user_input:
             APPLICATION_ID = user_input
     return client_id, client_secret
@@ -106,6 +108,9 @@ def pin_auth(pin=None, client_id=None, client_secret=None, store=False):
 
     :param pin: Optional Trakt API PIN code. If one is not specified, you will
         be prompted to go generate one
+    :param client_id: The oauth client_id for authenticating to the trakt API.
+    :param client_secret: The oauth client_secret for authenticating to the
+        trakt API.
     :param store: Boolean flag used to determine if your trakt api auth data
         should be stored locally on the system. Default is :const:`False` for
         the security conscious
@@ -126,14 +131,14 @@ def pin_auth(pin=None, client_id=None, client_secret=None, store=False):
               'url and log in to generate one.')
         pin_url = 'https://trakt.tv/pin/{id}'.format(id=APPLICATION_ID)
         print(pin_url)
-        pin = six.moves.input('Please enter your PIN: ')
+        pin = input('Please enter your PIN: ')
     args = {'code': pin,
             'redirect_uri': REDIRECT_URI,
             'grant_type': 'authorization_code',
             'client_id': CLIENT_ID,
             'client_secret': CLIENT_SECRET}
 
-    response = requests.post(''.join([BASE_URL, '/oauth/token']), data=args)
+    response = session.post(''.join([BASE_URL, '/oauth/token']), data=args)
     OAUTH_TOKEN = response.json().get('access_token', None)
 
     if store:
@@ -152,7 +157,7 @@ def _terminal_oauth_pin(authorization_url):
     print('Please go here and authorize,', authorization_url)
 
     # Get the authorization verifier code from the callback url
-    response = six.moves.input('Paste the Code returned here: ')
+    response = input('Paste the Code returned here: ')
     return response
 
 
@@ -210,9 +215,6 @@ def get_device_code(client_id=None, client_secret=None):
     authentication-devices/device-code
     :param client_id: Your Trakt OAuth Application's Client ID
     :param client_secret: Your Trakt OAuth Application's Client Secret
-    :param store: Boolean flag used to determine if your trakt api auth data
-        should be stored locally on the system. Default is :const:`False` for
-        the security conscious
     :return: Your OAuth device code.
     """
     global CLIENT_ID, CLIENT_SECRET, OAUTH_TOKEN
@@ -225,8 +227,8 @@ def get_device_code(client_id=None, client_secret=None):
     headers = {'Content-Type': 'application/json'}
     data = {"client_id": CLIENT_ID}
 
-    device_response = requests.post(device_code_url, json=data,
-                                    headers=headers).json()
+    device_response = session.post(device_code_url,
+                                   json=data, headers=headers).json()
     print('Your user code is: {user_code}, please navigate to '
           '{verification_url} to authenticate'.format(
             user_code=device_response.get('user_code'),
@@ -266,8 +268,9 @@ def get_device_token(device_code, client_id=None, client_secret=None,
         "client_secret": CLIENT_SECRET
     }
 
-    response = requests.post(urljoin(BASE_URL, '/oauth/device/token'),
-                             json=data)
+    response = session.post(
+        urljoin(BASE_URL, '/oauth/device/token'), json=data
+    )
 
     # We only get json on success.
     if response.status_code == 200:
@@ -367,8 +370,8 @@ Comment = namedtuple('Comment', ['id', 'parent_id', 'created_at', 'comment',
 def _validate_token(s):
     """Check if current OAuth token has not expired"""
     global OAUTH_TOKEN_VALID
-    current = datetime.utcnow()
-    expires_at = datetime.utcfromtimestamp(OAUTH_EXPIRES_AT)
+    current = datetime.now(tz=timezone.utc)
+    expires_at = datetime.fromtimestamp(OAUTH_EXPIRES_AT, tz=timezone.utc)
     if expires_at - current > timedelta(days=2):
         OAUTH_TOKEN_VALID = True
     else:
@@ -387,7 +390,7 @@ def _refresh_token(s):
                 'redirect_uri': REDIRECT_URI,
                 'grant_type': 'refresh_token'
             }
-    response = requests.post(url, json=data, headers=HEADERS)
+    response = session.post(url, json=data, headers=HEADERS)
     s.logger.debug('RESPONSE [post] (%s): %s', url, str(response))
     if response.status_code == 200:
         data = response.json()
@@ -397,7 +400,7 @@ def _refresh_token(s):
         OAUTH_TOKEN_VALID = True
         s.logger.info(
             "OAuth token successfully refreshed, valid until",
-            datetime.fromtimestamp(OAUTH_EXPIRES_AT)
+            datetime.fromtimestamp(OAUTH_EXPIRES_AT, tz=timezone.utc)
         )
         _store(
             CLIENT_ID=CLIENT_ID, CLIENT_SECRET=CLIENT_SECRET,
@@ -410,7 +413,7 @@ def _refresh_token(s):
             "refresh_token is invalid"
         )
     elif response.status_code in s.error_map:
-        raise s.error_map[response.status_code]()
+        raise s.error_map[response.status_code](response)
 
 
 def load_config():
@@ -515,14 +518,14 @@ class Core(object):
         self.logger.debug('headers: %s', str(HEADERS))
         self.logger.debug('method, url :: %s, %s', method, url)
         if method == 'get':  # GETs need to pass data as params, not body
-            response = requests.request(method, url, params=data,
-                                        headers=HEADERS)
+            response = session.request(method, url, headers=HEADERS,
+                                       params=data)
         else:
-            response = requests.request(method, url, data=json.dumps(data),
-                                        headers=HEADERS)
+            response = session.request(method, url, headers=HEADERS,
+                                       data=json.dumps(data))
         self.logger.debug('RESPONSE [%s] (%s): %s', method, url, str(response))
         if response.status_code in self.error_map:
-            raise self.error_map[response.status_code]()
+            raise self.error_map[response.status_code](response)
         elif response.status_code == 204:  # HTTP no content
             return None
         json_data = json.loads(response.content.decode('UTF-8', 'ignore'))
